==> weather_block-7.x-1.7.tar.gz: weather_block/weather_block.tpl.php <==
<?php

/**
 * @file: Template for the module output
 */

   print "<div class='forecast_menu'>" . $menu . "</div>";

   print "<div class='forecast_location'>" . $location->name . "</div>";

   print drupal_render($form);

   $i = 0;

   foreach($content as $key => $val) {

     print "<div class='weather_forecast'>";

     if($service == 'yahoo_weather' && $key == 0) {
       print "<div class='forecast_day_wrapper'>" . $val['day'] . "</div>";
       print "<div class='forecast_icon'><img src='" . $val['icon'] . "'></img></div>";
       print "<div class='forecast_temp_current_wrapper'><div class='forecast_temp_current'>" . t('Temperature') . "</div><div class='forecast_temp_current_value'> " . $val['current'] . "</div></div>";
       print $val['wind'];
       print "<div class='forecast_humidity_wrapper'><div class='forecast_humidity'>" . t('Humidity') . "</div><div class='forecast_humidity_value'>" . $val['humidity'] . "</div>";
     }
     else if ($service == 'yahoo_weather' && $key == 1) {
       print "<div class='forecast_day_wrapper'>" . $val['day'] . "</div>";
       print "<div class='forecast_icon'><img src='" . $val['icon'] . "'></img></div>";
       print "<div class='forecast_temp_low_wrapper'><div class='forecast_temp_low'>" . t('Low') . "</div><div class='forecast_temp_low_value'> " . $val['low'] . "</div></div>";
       print "<div class='forecast_temp_high_wrapper'><div class='forecast_temp_high'>" . t('High') . "</div><div class='forecast_temp_high_value'> " . $val['high'] . "</div></div>";
     }
     if($service == 'world_weather_online' && $key == 0) {
       print "<div class='forecast_day_wrapper'>" . $val['day'] . "</div>";
       print "<div class='forecast_icon'><img src='" . $val['icon'] . "'></img></div>";
       print "<div class='forecast_temp_current_wrapper'><div class='forecast_temp_current'>" . t('Temperature') . "</div><div class='forecast_temp_current_value'> " . $val['low'] . "</div></div>";
       print "<div class='forecast_wind_wrapper'><div class='forecast_wind'>" . t('Wind') . "</div><div class='forecast_wind_value'> " . $val['wind'] . "</div></div>";
       print "<div class='forecast_humidity_wrapper'><div class='forecast_humidity'>" . t('Humidity') . "</div><div class='forecast_humidity_value'>" . $val['humidity'] . "</div>";
     }
     else if ($service == 'world_weather_online' && $key != 0) {
       print "<div class='forecast_day_wrapper'>" . $val['day'] . "</div>";
       print "<div class='forecast_icon'><img src='" . $val['icon'] . "'></img></div>";
       print "<div class='forecast_temp_low_wrapper'><div class='forecast_temp_low'>" . t('Low') . "</div><div class='forecast_temp_low_value'> " . $val['low'] . "</div></div>";
       print "<div class='forecast_temp_high_wrapper'><div class='forecast_temp_high'>" . t('High') . "</div><div class='forecast_temp_high_value'> " . $val['high'] . "</div></div>";
       print "<div class='forecast_wind_wrapper'><div class='forecast_wind'>" . t('Wind') . "</div><div class='forecast_wind_value'> " . $val['wind'] . "</div></div>";
     }
     else {
       print "<div class='forecast_day_wrapper'>" . $val['day'] . "</div>";
       print "<div class='forecast_icon'><img src='" . $val['icon'] . "'></img></div>";
       print "<div class='forecast_temp_low_wrapper'><div class='forecast_temp_low'>" . t('Low') . "</div><div class='forecast_temp_low_value'> " . $val['low'] . "</div></div>";
       print "<div class='forecast_temp_high_wrapper'><div class='forecast_temp_high'>" . t('High') . "</div><div class='forecast_temp_high_value'> " . $val['high'] . "</div></div>";
     }

     print "</div>";
   }

?>

==> weather_block-7.x-1.8.tar.gz: weather_block/weather_block.tpl.php <==
<?php

/**
 * @file: Template for the module output
 */

   print "<div class='forecast_menu'>" . $menu . "</div>";

   print "<div class='forecast_location'>" . $location->name . "</div>";

   print drupal_render($form);

   $i = 0;

   foreach($content as $key => $val) {

     print "<div class='weather_forecast'>";

     if($service == 'yahoo_weather' && $key == 0) {
       print "<div class='forecast_day_wrapper'>" . $val['day'] . "</div>";
       print "<div class='forecast_icon'><img src='" . $val['icon'] . "'></img></div>";
       print "<div class='weather_current'><div class='forecast_temp_current_wrapper'><div class='forecast_temp_current'>" . t('Temperature') . "</div><div class='forecast_temp_current_value'> " . $val['current'] . "</div></div>";
       print "<div class='forecast_wind_wrapper'><div class='forecast_wind'>" . t('Wind') . "</div><div class='forecast_wind_value'> " . $val['wind'] . "</div></div>";
       print "<div class='forecast_humidity_wrapper'><div class='forecast_humidity'>" . t('Humidity') . "</div><div class='forecast_humidity_value'>" . $val['humidity'] . "</div></div></div>";
     }
     else if ($service == 'yahoo_weather' && $key == 1) {
       print "<div class='forecast_day_wrapper'>" . $val['day'] . "</div>";
       print "<div class='forecast_icon'><img src='" . $val['icon'] . "'></img></div>";
       print "<div class='forecast_temp_low_wrapper'><div class='forecast_temp_low'>" . t('Low') . "</div><div class='forecast_temp_low_value'> " . $val['low'] . "</div></div>";
       print "<div class='forecast_temp_high_wrapper'><div class='forecast_temp_high'>" . t('High') . "</div><div class='forecast_temp_high_value'> " . $val['high'] . "</div></div>";
     }
     if($service == 'world_weather_online' && $key == 0) {
       print "<div class='forecast_day_wrapper'>" . $val['day'] . "</div>";
       print "<div class='forecast_icon'><img src='" . $val['icon'] . "'></img></div>";
       print "<div class='weather_current'><div class='forecast_temp_current_wrapper'><div class='forecast_temp_current'>" . t('Temperature') . "</div><div class='forecast_temp_current_value'> " . $val['low'] . "</div></div>";
       print "<div class='forecast_wind_wrapper'><div class='forecast_wind'>" . t('Wind') . "</div><div class='forecast_wind_value'> " . $val['wind'] . "</div></div>";
       print "<div class='forecast_humidity_wrapper'><div class='forecast_humidity'>" . t('Humidity') . "</div><div class='forecast_humidity_value'>" . $val['humidity'] . "</div></div></div>";
     }
     else if ($service == 'world_weather_online' && $key != 0) {
       print "<div class='forecast_day_wrapper'>" . $val['day'] . "</div>";
       print "<div class='forecast_icon'><img src='" . $val['icon'] . "'></img></div>";
       print "<div class='forecast_temp_low_wrapper'><div class='forecast_temp_low'>" . t('Low') . "</div><div class='forecast_temp_low_value'> " . $val['low'] . "</div></div>";
       print "<div class='forecast_temp_high_wrapper'><div class='forecast_temp_high'>" . t('High') . "</div><div class='forecast_temp_high_value'> " . $val['high'] . "</div></div>";
       print "<div class='forecast_wind_wrapper'><div class='forecast_wind'>" . t('Wind') . "</div><div class='forecast_wind_value'> " . $val['wind'] . "</div></div>";
     }
     else {
       print "<div class='forecast_day_wrapper'>" . $val['day'] . "</div>";
       print "<div class='forecast_icon'><img src='" . $val['icon'] . "'></img></div>";
       print "<div class='forecast_temp_low_wrapper'><div class='forecast_temp_low'>" . t('Low') . "</div><div class='forecast_temp_low_value'> " . $val['low'] . "</div></div>";
       print "<div class='forecast_temp_high_wrapper'><div class='forecast_temp_high'>" . t('High') . "</div><div class='forecast_temp_high_value'> " . $val['high'] . "</div></div>";
     }

     print "</div>";
   }

?>
